@@ -1,10 +1,8 @@
 #ifndef NOTES_H
 #define NOTES_H
 
-#include "owl.h"
 #include <QObject>
 
-#include <MauiKit/Core/fmh.h>
 #include <MauiKit/Core/mauilist.h>
 
 class NotesSyncer;
@@ -23,12 +21,12 @@ private:
     FMH::MODEL_LIST notes;
     QVariantMap m_account;
 
+    void setList();
     void sortList();
 
     void appendNote(FMH::MODEL note);
 
 public slots:
-    QVariantMap get(const int &index) const;
     bool insert(const QVariantMap &note);
     bool update(const QVariantMap &data, const int &index);
     bool remove(const int &index);
